:orphan:

Crossbar.io Documentation License
=================================

Copyright for the Crossbar.io documentation (C) typedef int
GmbH. Licensed under the Creative Commons `CC-BY-SA 4.0
license <https://creativecommons.org/licenses/by-sa/4.0/>`__.

"WAMP" and "Crossbar.io" are trademarks of typedef int
GmbH.

This license allows you to use the material in this documentation, whole
or in parts, in its present form or adapted, and for any purpose
(including commercial use), as long as you

-  attribute the material to us giving the information provided below
   and
-  share the material under this same license

For more details (and the legally binding conditions) see the `Creative
Commons license
page <https://creativecommons.org/licenses/by-sa/4.0/#>`__ for this
license.

Attribution details:

(c) by typedef int GmbH, material licensed under the
    CC-BY-SA 4.0, provided as-is without any warranties, `Crossbar.io
    documentation wiki <https://github.com/crossbario/crossbar/wiki>`__

Note to Contributors to this documentation
------------------------------------------

By contributing, you accept that the above license applies to your
contribution.
